# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .ping import (
    PingResource,
    AsyncPingResource,
    PingResourceWithRawResponse,
    AsyncPingResourceWithRawResponse,
    PingResourceWithStreamingResponse,
    AsyncPingResourceWithStreamingResponse,
)
from .credits import (
    CreditsResource,
    AsyncCreditsResource,
    CreditsResourceWithRawResponse,
    AsyncCreditsResourceWithRawResponse,
    CreditsResourceWithStreamingResponse,
    AsyncCreditsResourceWithStreamingResponse,
)
from .generations import (
    GenerationsResource,
    AsyncGenerationsResource,
    GenerationsResourceWithRawResponse,
    AsyncGenerationsResourceWithRawResponse,
    GenerationsResourceWithStreamingResponse,
    AsyncGenerationsResourceWithStreamingResponse,
)

__all__ = [
    "GenerationsResource",
    "AsyncGenerationsResource",
    "GenerationsResourceWithRawResponse",
    "AsyncGenerationsResourceWithRawResponse",
    "GenerationsResourceWithStreamingResponse",
    "AsyncGenerationsResourceWithStreamingResponse",
    "PingResource",
    "AsyncPingResource",
    "PingResourceWithRawResponse",
    "AsyncPingResourceWithRawResponse",
    "PingResourceWithStreamingResponse",
    "AsyncPingResourceWithStreamingResponse",
    "CreditsResource",
    "AsyncCreditsResource",
    "CreditsResourceWithRawResponse",
    "AsyncCreditsResourceWithRawResponse",
    "CreditsResourceWithStreamingResponse",
    "AsyncCreditsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union
from typing_extensions import Literal, TypedDict

__all__ = ["GenerationUpscaleParams"]


class GenerationUpscaleParams(TypedDict, total=False):
    callback_url: str
    """The callback URL for the upscale"""

    generation_type: Literal["upscale_video"]

    resolution: Union[Literal["540p", "720p", "1080p", "4k"], str]
    """The resolution of the upscale"""
